@@ -6,7 +6,7 @@
 #          The projects homepage is dev.cmsmadesimple.org/projects/content2/
 #          CMS Made Simple is (c) 2004-2011 by Ted Kulp
 #          The projects homepage is: cmsmadesimple.org
-# Version: 0.9.1
+# Version: 0.9.2
 # File   : AdvancedContent.module.php
 # Purpose: initial module class.
 # License: GPL
@@ -112,7 +112,7 @@ class AdvancedContent extends CMSModule
 	
 	public final function GetVersion()
 	{
-		return '0.9.1';
+		return '0.9.2';
 	}
 	
 	public final function GetHelp()
@@ -262,7 +262,7 @@ class AdvancedContent extends CMSModule
 	
 	public final function MinimumCMSVersion()
 	{
-		return "1.9";
+		return "1.10.1";
 	}
 	
 	public final function MaximumCMSVersion()
