@@ -6,7 +6,7 @@
 #          The projects homepage is dev.cmsmadesimple.org/projects/content2/
 #          CMS Made Simple is (c) 2004-2011 by Ted Kulp
 #          The projects homepage is: cmsmadesimple.org
-# Version: 0.9.1
+# Version: 0.9.2
 # File   : action.savePrefs.php
 # Purpose: saves the preferences in the database
 # License: GPL
@@ -21,6 +21,14 @@ if(isset($params['submit']) || isset($params['submit_prefs']))
 	{
 		$this->SetPreference('use_advanced_pageoptions', $params['use_advanced_pageoptions']);
 	}
+	if(!$this->GetPreference('use_advanced_pageoptions', 0))
+	{
+		$this->RemoveEventHandler( 'Core', 'ContentPostRender');
+	}
+	else
+	{
+		$this->AddEventHandler( 'Core', 'ContentPostRender', false );
+	}
 	if(isset($params['uninstall_action']))
 	{
 		$this->SetPreference('uninstall_action', $params['uninstall_action']);
