@@ -6,7 +6,7 @@
 #          The projects homepage is http://dev.cmsmadesimple.org/projects/content2/
 #          CMS Made Simple is (c) 2004-2011 by Ted Kulp
 #          The projects homepage is: http://www.cmsmadesimple.org
-# Version: 0.9.1
+# Version: 0.9.2
 # File   : contenttype.Content2.php
 # Purpose: the content object
 # License: GPL
@@ -82,6 +82,7 @@ class Content2 extends CMSModuleContentType
 	
 	function FriendlyName()
 	{
+		$AdvancedContent =& cms_utils::get_module('AdvancedContent');
 		if(basename($_SERVER['PHP_SELF']) == 'listcontent.php')
 		{
 			$addTxt = array();
@@ -98,43 +99,43 @@ class Content2 extends CMSModuleContentType
 					$selectedGroups = $this->GetProperty('feu_access');
 					if(count($selectedGroups))
 					{
-						$addTxt[] = '-&nbsp;'.$this->lang('frontendaccess').': <ul><li>' . implode('</li><li>',array_keys(array_intersect($feusers->GetGroupList(), $selectedGroups))).'</li></ul>';
+						$addTxt[] = '-&nbsp;'.$AdvancedContent->lang('frontendaccess').': <ul><li>' . implode('</li><li>',array_keys(array_intersect($feusers->GetGroupList(), $selectedGroups))).'</li></ul>';
 						$redirectPage = $this->GetProperty('redirect_page');
 						if($redirectPage)
 						{
-							$addTxt[] = '-&nbsp;' . $this->lang('redirectpage') . ': '.$redirectPage.'<br />';
+							$addTxt[] = '-&nbsp;' . $AdvancedContent->lang('redirectpage') . ': '.$redirectPage.'<br />';
 						}
 						$params = $this->GetProperty('feu_params');
 						if(count($params[1]))
 						{
-							$addTxt[] = '-&nbsp;' . $this->lang('feu_params') . ': <ul><li>' . implode('</li><li>',$params[1]).'</li></ul>';
+							$addTxt[] = '-&nbsp;' . $AdvancedContent->lang('feu_params') . ': <ul><li>' . implode('</li><li>',$params[1]).'</li></ul>';
 						}
 						$params = $this->GetProperty('custom_params');
 						if(count($params[1]))
 						{
-							$addTxt[] = '-&nbsp;' . $this->lang('custom_params') . ': <ul><li>' . implode('</li><li>',$params[1]).'</li></ul>';
+							$addTxt[] = '-&nbsp;' . $AdvancedContent->lang('custom_params') . ': <ul><li>' . implode('</li><li>',$params[1]).'</li></ul>';
 						}
 					}
 					$hide_menu_item = $this->GetProperty('hide_menu_item');
 					if($hide_menu_item == 2 || ($hide_menu_item == 1 && count($selectedGroups)))
 					{
-						$addTxt[] = '-&nbsp;' . $this->lang('hide_menu_item') . ': '. ($hide_menu_item == 1 ? $this->lang('loggedout') : $this->lang('loggedin')).'<br />';
+						$addTxt[] = '-&nbsp;' . $AdvancedContent->lang('hide_menu_item') . ': '. ($hide_menu_item == 1 ? $AdvancedContent->lang('loggedout') : $AdvancedContent->lang('loggedin')).'<br />';
 					}
 				}
 				if($this->GetProperty('use_expire_date'))
 				{
 					setlocale(LC_ALL, get_preference(get_userid(), 'default_cms_language'));
-					$addTxt[]   = '-&nbsp;'.$this->lang('startdate').': '.strftime('%x %H:%M',$this->GetProperty('start_date')).'<br />';
-					$addTxt[]   = '-&nbsp;'.$this->lang('enddate').': '.strftime('%x %H:%M',$this->GetProperty('end_date')).'<br />';
+					$addTxt[]   = '-&nbsp;'.$AdvancedContent->lang('startdate').': '.strftime('%x %H:%M',$this->GetProperty('start_date')).'<br />';
+					$addTxt[]   = '-&nbsp;'.$AdvancedContent->lang('enddate').': '.strftime('%x %H:%M',$this->GetProperty('end_date')).'<br />';
 				}
 			}
 			if(count($addTxt))
 			{
-				return '<span style="position:relative;text-decoration:underline;cursor:pointer;display:block" onmouseover="document.getElementById(\''.$this->mId.'_info\').style.display = \'block\';" onmouseout="document.getElementById(\''.$this->mId.'_info\').style.display = \'none\';">' . $this->lang('AdvancedContent') . '<span id="'.$this->mId.'_info" style="text-decoration:none;background-color:#FFF;border:1px solid #000;position:absolute;padding:5px;display:none;-moz-box-shadow:1px 1px 10px #666666;-webkit-box-shadow:1px 1px 10px #666666;box-shadow:1px 1px 10px #666666;z-index:999;white-space:nowrap">' . implode('',$addTxt) . '</span></span>';
+				return '<span style="position:relative;text-decoration:underline;cursor:pointer;display:block" onmouseover="document.getElementById(\''.$this->mId.'_info\').style.display = \'block\';" onmouseout="document.getElementById(\''.$this->mId.'_info\').style.display = \'none\';">' . $AdvancedContent->lang('AdvancedContent') . '<span id="'.$this->mId.'_info" style="text-decoration:none;background-color:#FFF;border:1px solid #000;position:absolute;padding:5px;display:none;-moz-box-shadow:1px 1px 10px #666666;-webkit-box-shadow:1px 1px 10px #666666;box-shadow:1px 1px 10px #666666;z-index:999;white-space:nowrap">' . implode('',$addTxt) . '</span></span>';
 			}
 		}
 		
-		return $this->lang('AdvancedContent');
+		return $AdvancedContent->lang('AdvancedContent');
 	}
 	
 	function ShowInMenu()
@@ -581,7 +582,7 @@ class Content2 extends CMSModuleContentType
 			{
 				$this->_blockGroups[$blockGroup]['display'] = $AdvancedContent->GetItemDisplay('group', $blockGroup, $this->mId, $this->mTemplateId, !$this->_blockGroups[$blockGroup]['collapse']);
 					$this->_blockGroups[$blockGroup]['pref_url'] = str_replace('&amp;','&',
-						$AdvancedContent->CreateLink('m1_', 'savePrefs', '', $this->lang('toggle_group'),
+						$AdvancedContent->CreateLink('m1_', 'savePrefs', '', $AdvancedContent->lang('toggle_group'),
 							array('item_type'=>'group',
 								'disable_theme'=>true,
 								'ajax'=>true,
@@ -688,7 +689,7 @@ class Content2 extends CMSModuleContentType
 		$AdvancedContent->smarty->assign('getproperty_url', 
 			str_replace('&amp;','&',
 				$AdvancedContent->CreateLink('m1_', 'getproperty', '', 
-					$this->lang('getproperty'),
+					$AdvancedContent->lang('getproperty'),
 					array('disable_theme'=>true,'ajax'=>true),
 					'', true)
 			)
@@ -706,8 +707,7 @@ class Content2 extends CMSModuleContentType
 		
 		# ugly hack!
 		$headers_list = headers_list();
-		$output = str_replace('</head>', ( $tab == 0 ? $AdvancedContent->GetHeaderHTML() : '') . $headerHTML . '</head>', ob_get_contents());
-		@ob_end_clean();
+		$output = str_replace('</head>', ( $tab == 0 ? $AdvancedContent->GetHeaderHTML() : '') . $headerHTML . '</head>', ob_get_clean());
 		@ob_start();
 		foreach($headers_list as $header)
 		{
@@ -740,7 +740,7 @@ class Content2 extends CMSModuleContentType
 		{
 			if($contentBlock->GetBlockProperty('required') && $this->GetProperty($contentBlock->GetBlockProperty('id')) == '')
 			{
-				$errors[] = lang('nofieldgiven', array($contentBlock->GetBlockProperty('name')));
+				$errors[] = lang('nofieldgiven', array($contentBlock->GetBlockProperty('label')));
 			}
 		}
 		if($this->GetPropertyValue('use_expire_date') && check_permission(get_userid(), 'Manage AdvancedContent Options') && $this->GetProperty('end_date') <= $this->GetProperty('start_date'))
@@ -1003,7 +1003,7 @@ class Content2 extends CMSModuleContentType
 					{
 						$contentBlock->SetBlockProperty('id', md5($contentBlock->GetBlockProperty('id') . $j));
 						$contentBlock->SetBlockProperty('type', '');
-						$contentBlock->SetBlockProperty('default', $this->lang('error_basicattrib', $contentBlock->GetBlockProperty('name')));
+						$contentBlock->SetBlockProperty('default', $AdvancedContent->lang('error_basicattrib', $contentBlock->GetBlockProperty('name')));
 						$this->_register_content_block($contentBlock);
 						continue;
 					}
@@ -1918,18 +1918,6 @@ class Content2 extends CMSModuleContentType
 	{
 		return cms_utils::get_module($module_name, $module_version);
 	}
-	
-	/**
-	 * Just for backwards compatibility
-	 */
-	public function SetPropertyValueNoLoad($name, $value)
-	{
-		if(method_exists('parent', 'SetPropertyValueNoLoad'))
-		{
-			return parent::SetPropertyValueNoLoad($name, $value);
-		}
-		return parent::SetPropertyValue($name, $value);
-	}
 }
 
 ?>
