@@ -6,7 +6,7 @@
 #          The projects homepage is http://dev.cmsmadesimple.org/projects/content2/
 #          CMS Made Simple is (c) 2004-2011 by Ted Kulp (wishy@cmsmadesimple.org)
 #          The projects homepage is: http://www.cmsmadesimple.org
-# Version: 0.9.1
+# Version: 0.9.2
 # File   : method.upgrade.php
 # Purpose: performs a module upgrade
 # License: GPL
@@ -36,6 +36,13 @@ switch($current_version)
 </div>');
 	
 		$current_version = '0.9';
+		
+	case '0.9.1':
+		if(!$this->GetPreference('use_advanced_pageoptions', 0))
+		{
+			$this->RemoveEventHandler( 'Core', 'ContentPostRender');
+		}
+		$current_version = '0.9.2';
 }
 
 ?>
